<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>AccessCert</name>
    <message>
        <source>Error downloading server access certificate!
%1</source>
        <translation>Ошибка при загрузке справки допуска!
%1</translation>
    </message>
    <message>
        <source>Empty result!</source>
        <translation>Пустой ответ!</translation>
    </message>
    <message>
        <source>Error parsing server access certificate result!</source>
        <translation>Ошибка при чтении справки допуска!</translation>
    </message>
    <message>
        <source>Error reading server access certificate - empty content!</source>
        <translation>Ошибка при чтении справки допуска! - содержание пустое!</translation>
    </message>
    <message>
        <source>Failed to save server access certificate file to %1!
%2</source>
        <translation>Ошибка при сохранении справки допуска! %1!
%2</translation>
    </message>
    <message>
        <source>Server access certificate</source>
        <translation>Справка допуска</translation>
    </message>
    <message>
        <source>Did not find any server access certificate!
Start downloading?</source>
        <translation>Отсутствует справка допуска!
Начнём загрузку?</translation>
    </message>
    <message>
        <source>Failed to read server access certificate!
Start downloading?</source>
        <translation>Не удалось загрузить справку допуска!
Начнём загрузку?</translation>
    </message>
    <message>
        <source>Server access certificate password is not valid!
Start downloading?</source>
        <translation>Пароль справки допуска неверен!
Начнём загрузку?</translation>
    </message>
    <message>
        <source>Server access certificate is not valid!
Start downloading?</source>
        <translation>Справка допуска не действительна!
Начнём загрузку?</translation>
    </message>
    <message>
        <source>Server access certificate is about to expire!
Start downloading?</source>
        <translation>Срок действия справки допуска скоро истечёт!
Начнём загрузку?</translation>
    </message>
</context>
<context>
    <name>DigiDoc</name>
    <message>
        <source>Container is not open</source>
        <translation>Контейнер не открыт</translation>
    </message>
    <message>
        <source>Cannot add files to signed container</source>
        <translation>Нельзя добавлять файлы в подписанный контейнер</translation>
    </message>
    <message>
        <source>Missing document</source>
        <translation>Документ отсутствует</translation>
    </message>
    <message>
        <source>Missing signature</source>
        <translation>Подпись отсутствует</translation>
    </message>
    <message>
        <source>Cannot add signature to empty container</source>
        <translation>Нельзя добавить подпись в пустой контейнер</translation>
    </message>
    <message>
        <source>PIN Incorrect</source>
        <translation>Неверный PIN</translation>
    </message>
    <message>
        <source>PIN Locked</source>
        <translation>PIN заблокирован</translation>
    </message>
    <message>
        <source>PIN Login failed</source>
        <translation>Введенный PIN неверен</translation>
    </message>
    <message>
        <source>Certificate status revoked</source>
        <translation>Сертификат недействителен</translation>
    </message>
    <message>
        <source>Certificate status unknown</source>
        <translation>Статус сертификата неизвестен</translation>
    </message>
    <message>
        <source>Check your computer time</source>
        <translation>Проверьте время Вашего компьютера</translation>
    </message>
    <message>
        <source>An error occurred while opening the document.&lt;br /&gt;%1</source>
        <translation>При открытии документа произошла ошибка&lt;br /&gt;%1</translation>
    </message>
    <message>
        <source>Server access certificate is required</source>
        <translation>Необходима справка допуска</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Next</source>
        <translation>Дальше</translation>
    </message>
    <message>
        <source>Sign</source>
        <translation>Подписать</translation>
    </message>
    <message>
        <source>Add signature</source>
        <translation>Добавить подпись</translation>
    </message>
    <message>
        <source>Save file</source>
        <translation>Сохранить файл</translation>
    </message>
    <message>
        <source>Documents (*.bdoc *.ddoc)</source>
        <translation>Документы (*.bdoc *.ddoc)</translation>
    </message>
    <message>
        <source>File already in container</source>
        <translation>Файл уже в контейнере</translation>
    </message>
    <message>
        <source>%1&lt;br /&gt;already in container, ovewrite?</source>
        <translation>%1&lt;br /&gt;уже в контейнере, переписать?</translation>
    </message>
    <message>
        <source>Failed to start process &apos;qdigidoccrypto&apos;</source>
        <translation>Запуск процесса &apos;Digidoc Crypto&apos; неудачен</translation>
    </message>
    <message>
        <source>Failed to start process &apos;qesteidutil&apos;</source>
        <translation>Запуск процесса &apos;qesteidutil&apos; неудачен</translation>
    </message>
    <message>
        <source>Select documents</source>
        <translation>Добавить файлы</translation>
    </message>
    <message>
        <source>Save container</source>
        <translation>Сохранить контейнер</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Keep</source>
        <translation>Оставить</translation>
    </message>
    <message>
        <source>Open container</source>
        <translation>Открыть контейнер</translation>
    </message>
    <message>
        <source>Select folder where files will be stored</source>
        <translation>Выберите папку для сохранения файлов</translation>
    </message>
    <message>
        <source>Container:</source>
        <translation>Контейнер:</translation>
    </message>
    <message>
        <source>This container is signed by you</source>
        <translation>Данный контейнер подписан вами</translation>
    </message>
    <message>
        <source>You have not signed this container</source>
        <translation>Данный контейнер не подписан вами</translation>
    </message>
    <message>
        <source>Container is unsigned</source>
        <translation>Контейнер не подписан</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Подпись</translation>
    </message>
    <message>
        <source>Loading data</source>
        <translation>Читаю данные</translation>
    </message>
    <message>
        <source>No card in reader</source>
        <translation>В считывателе нет карты</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Помощь</translation>
    </message>
    <message>
        <source>Use ID-card</source>
        <translation>Использовать ID-карту</translation>
    </message>
    <message>
        <source>Use Mobile ID</source>
        <translation>Использовать Mobiil-ID</translation>
    </message>
    <message>
        <source>Mobile number:</source>
        <translation>Номер моб. телефона:</translation>
    </message>
    <message>
        <source>Personal code:</source>
        <translation>Личный код:</translation>
    </message>
    <message>
        <source>I want to:</source>
        <translation>Я желаю:</translation>
    </message>
    <message>
        <source>Sign documents</source>
        <translation>Подписать документы</translation>
    </message>
    <message>
        <source>View signed document content</source>
        <translation>Просмотреть подписанный документ</translation>
    </message>
    <message>
        <source>Encrypt files for secure transfer</source>
        <translation>Зашифровать файлы для безопасной передачи</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;
&lt;/head&gt;&lt;body&gt;
&lt;p style=&quot; font: 12px &apos;Arial,Liberation Sans&apos;;&quot;&gt;
Digital signing.&lt;br /&gt;&lt;br /&gt;
Digital signing is equal to physical signing. To sign a document you need an ID-card with a valid and usable signature certificate.&lt;br /&gt;&lt;br /&gt;
Signing is done via PIN2 code&lt;br /&gt;&lt;br /&gt;
Also an active internet connection is needed.&lt;/p&gt;
&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;
&lt;/head&gt;&lt;body&gt;
&lt;p style=&quot; font: 12px &apos;Arial,Liberation Sans&apos;;&quot;&gt;
Подписывание документов.&lt;br /&gt;&lt;br /&gt;
Цифровая подпись аналогична физической подписи. Для цифровой подписи нужна ID-карта, которая имеет действующие сертификаты .&lt;br /&gt;&lt;br /&gt;
При подписывании документов нужен PIN2 код.&lt;br /&gt;&lt;br /&gt;
Для цифровой подписи необходимо подключение к интернету.&lt;/p&gt;
&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Skip this intro</source>
        <translation>Больше не показывать</translation>
    </message>
    <message>
        <source>Container content:</source>
        <translation>Содержание контейнера:</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Arial, Liberation Sans&apos;; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Roll ...&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Arial, Liberation Sans&apos;; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Роль ...&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Role</source>
        <translation>Роль</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Arial, Liberation Sans&apos;; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Resolution ...&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Arial, Liberation Sans&apos;; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Резолюция ...&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Резолюция</translation>
    </message>
    <message>
        <source>City</source>
        <translation>Город</translation>
    </message>
    <message>
        <source>State</source>
        <translation>Уезд</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>Страна</translation>
    </message>
    <message>
        <source>Zip</source>
        <translation>Индекс</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;addFile&quot;&gt;Add file&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;addFile&quot;&gt;Добавить файл&lt;/a&gt;</translation>
    </message>
    <message>
        <source>This container is </source>
        <translation>Данный контейнер</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;email&quot;&gt;Send container to email&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;email&quot;&gt;Отослать контейнер по эл. почте&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;print&quot;&gt;Print summary&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;print&quot;&gt;Распечатать подтверждающий лист&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;browse&quot;&gt;Browse container location&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;browse&quot;&gt;Открыть папку с контейнером&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;saveAs&quot;&gt;Save files to disk&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;saveAs&quot;&gt;Сохранить файлы на жёсткий диск&lt;/a&gt;</translation>
    </message>
    <message>
        <source>%1 already exists.&lt;br /&gt;Do you want replace it?</source>
        <translation>%1 уже существует.&lt;br /&gt;Заменить?</translation>
    </message>
    <message>
        <source>Personal code is not valid</source>
        <translation>Неверный личный код</translation>
    </message>
    <message>
        <source>NB! Test signature</source>
        <translation>NB! Пробная подпись</translation>
    </message>
    <message>
        <source>NB! Invalid signature</source>
        <translation>NB: Ошибочная подпись</translation>
    </message>
    <message>
        <source>You dont have suficient privilegs to write this fail into folder %1</source>
        <translation>У Вас недостаточно прав для записи файла в каталог %1</translation>
    </message>
    <message>
        <source>Documents (*.bdoc *.BDOC *.ddoc *.DDOC)</source>
        <translation>Документы (*.bdoc *.BDOC *.ddoc *.DDOC)</translation>
    </message>
    <message>
        <source>DigiDoc3 client</source>
        <translation>DigiDoc3 клиент</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message numerus="yes">
        <source>Signature(s)</source>
        <translation>
            <numerusform>Подпись</numerusform>
            <numerusform>Подписи</numerusform>
            <numerusform>Подписи</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>You added %n file(s) to container, but these are not signed yet.
Should I keep unsigned documents or remove these?</source>
        <translation>
            <numerusform>В контейнер добавлено %n файл(а), но они не подписаны.
Оставить неподписанный контейнер или стереть?</numerusform>
            <numerusform>В контейнер добавлено %n файл(а), но они не подписаны.
Оставить неподписанный контейнер или стереть?</numerusform>
            <numerusform>В контейнер добавлено %n файл(а), но они не подписаны.
Оставить неподписанный контейнер или стереть?</numerusform>
        </translation>
    </message>
    <message>
        <source>You can not add files to signed document. Remove all signatures before adding files.</source>
        <translation>К подписанному контейнеру нельзя добавить файлы. Удалите прежде с контейнера все подписи.</translation>
    </message>
    <message>
        <source>Sign certificate is not valid</source>
        <translation>Сертификат подписи недействителен</translation>
    </message>
</context>
<context>
    <name>MobileDialog</name>
    <message>
        <source>Signing in process</source>
        <translation>Подписывание</translation>
    </message>
    <message>
        <source>Request accepted</source>
        <translation>Запрос принят</translation>
    </message>
    <message>
        <source>Request timeout</source>
        <translation>Время запроса истекло</translation>
    </message>
    <message>
        <source>User denied or cancelled</source>
        <translation>Пользователю отказано</translation>
    </message>
    <message>
        <source>Got signature</source>
        <translation>Подпись получена</translation>
    </message>
    <message>
        <source>Request pending</source>
        <translation>Запрос в ожидании</translation>
    </message>
    <message>
        <source>Mobile-ID not ready, try again later</source>
        <translation>Mobiil-ID не готов, попробуйте позже</translation>
    </message>
    <message>
        <source>Phone absent</source>
        <translation>Нет телефона</translation>
    </message>
    <message>
        <source>Request sending error</source>
        <translation>Ошибка запроса</translation>
    </message>
    <message>
        <source>SIM error</source>
        <translation>Ошибка SIM карты</translation>
    </message>
    <message>
        <source>Service internal error</source>
        <translation>Внутренняя ошибка услуги</translation>
    </message>
    <message>
        <source>Signing with Mobile-ID</source>
        <translation>Подписывается с Mobiil-ID</translation>
    </message>
    <message>
        <source>Control code: %1</source>
        <translation>Контрольный код: %1</translation>
    </message>
    <message>
        <source>%v sec</source>
        <translation>%v сек</translation>
    </message>
    <message>
        <source>Connecting to SK server failed!
Please check your internet connection.</source>
        <translation>Ошибка при подключении с SK сервером
Пожалуйста проверьте подключение к интернету.</translation>
    </message>
    <message>
        <source>User is not a Mobile-ID client</source>
        <translation></translation>
    </message>
    <message>
        <source>ID and phone number do not match</source>
        <translation>Личный код и номер телефона не совпадают</translation>
    </message>
    <message>
        <source>Empty HTTP result</source>
        <translation>Пустой HTTP ответ</translation>
    </message>
    <message>
        <source>Failed to parse XML document</source>
        <translation>Ошибка при разборе XML документа</translation>
    </message>
    <message>
        <source>Not allowed to use OCSP service!
Please check your server access sertificate.</source>
        <translation>Не разрешено использовать OCSP услугу!
Пожалуйста проверьте действительность справки допуска.</translation>
    </message>
    <message>
        <source>Sign</source>
        <translation>Подписать</translation>
    </message>
    <message>
        <source>Certificate status unknown</source>
        <translation>Статус сертификата неизвестен</translation>
    </message>
</context>
<context>
    <name>PrintSheet</name>
    <message>
        <source>SIGNED FILES</source>
        <translation>ПОДПИСАННЫЕ ФАЙЛЫ</translation>
    </message>
    <message>
        <source>FILE NAME</source>
        <translation>ИМЯ ФАЙЛА</translation>
    </message>
    <message>
        <source>FILE SIZE</source>
        <translation>РАЗМЕР ФАЙЛА</translation>
    </message>
    <message>
        <source>SIGNERS</source>
        <translation>ПОДПИСАВШИЙСЯ</translation>
    </message>
    <message>
        <source>NAME</source>
        <translation>Имя</translation>
    </message>
    <message>
        <source>PERSONAL CODE</source>
        <translation>Личный код</translation>
    </message>
    <message>
        <source>TIME</source>
        <translation>Время</translation>
    </message>
    <message>
        <source>SIGNATURE</source>
        <translation>Подпись</translation>
    </message>
    <message>
        <source>NOTES</source>
        <translation>Замечания</translation>
    </message>
    <message>
        <source>VALIDITY CONFIRMATION SHEET</source>
        <translation>ЛИСТ ПОДТВЕРЖДЕНИЯ ДИГИТАЛЬНЫХ ПОДПИСЕЙ</translation>
    </message>
    <message>
        <source>NO.</source>
        <translation>№</translation>
    </message>
    <message>
        <source>VALIDITY OF SIGNATURE</source>
        <translation>ДЕЙСТВИТЕЛЬНОСТЬ ПОДПИСИ</translation>
    </message>
    <message>
        <source>VALID</source>
        <translation>действительна</translation>
    </message>
    <message>
        <source>NOT VALID</source>
        <translation>НЕДЕЙСТВИТЕЛЬНО</translation>
    </message>
    <message>
        <source>ROLE / RESOLUTION</source>
        <translation>Роль / заявление</translation>
    </message>
    <message>
        <source>PLACE OF CONFIRMATION (CITY, STATE, ZIP, COUNTRY)</source>
        <translation>МЕСТОПОЛОЖЕНИЕ ПОДПИСАВШЕГО (город, уезд, индекс, страна)</translation>
    </message>
    <message>
        <source>SERIAL NUMBER OF CERTIFICATE</source>
        <translation>СЕРИЙНЫЙ НОМЕР СЕРТИФИКАТА</translation>
    </message>
    <message>
        <source>ISSUER OF CERTIFICATE</source>
        <translation>ИМЯ ВЫДАВШЕГО СЕРТИФИКАТА</translation>
    </message>
    <message>
        <source>HASH VALUE OF ISSUER&apos;S PUBLIC KEY</source>
        <translation>СОКРАШЕНИЕ ПУБЛИЧНОГО КЛЮЧА ВЫДАВШЕГО СЕРТИФИКАТА</translation>
    </message>
    <message>
        <source>HASH VALUE OF VALIDITY CONFIRMATION (OCSP RESPONSE)</source>
        <translation>СОКРАЩЕНИЕ СООБЩЕНИЯ ПОДТВЕРЖДЕНИЯ ДЕЙСТВИТЕЛЬНОСТИ</translation>
    </message>
    <message>
        <source>The print out of files listed in the section &lt;b&gt;&quot;Signed Files&quot;&lt;/b&gt; are inseparable part of this Validity Confirmation Sheet.</source>
        <translation>Неотъемлемой частью этого листа подтверждения подписей является распечатка названных файлов на бумаге в разделе &lt;b&gt;&quot;Подписанные файлы&quot;&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>COMPANY</source>
        <translation>УЧЕРЕЖДЕНИЕ</translation>
    </message>
    <message>
        <source>REGISTER CODE</source>
        <translation>КОД РЕГИСТРА</translation>
    </message>
    <message>
        <source>UNKNOWN</source>
        <translation>Неизвестно</translation>
    </message>
</context>
<context>
    <name>QSigner</name>
    <message>
        <source>Failed to load PKCS#11 module</source>
        <translation>Неудачная загрузка модуля PKCS#11</translation>
    </message>
    <message>
        <source>PIN acquisition canceled.</source>
        <translation>Введение PIN кода было прервано.</translation>
    </message>
    <message>
        <source>Signing certificate is not selected.</source>
        <translation>Сертификат подписи не выбран.</translation>
    </message>
    <message>
        <source>Failed to login token</source>
        <translation>Неверный PIN</translation>
    </message>
    <message>
        <source>PIN Incorrect</source>
        <translation>Неверный PIN</translation>
    </message>
    <message>
        <source>PIN Locked</source>
        <translation>PIN заблокирован. Для разблокирования PIN пожалуйста используйте обслуживание ID-карты!</translation>
    </message>
    <message>
        <source>Failed to sign document</source>
        <translation>Не удалось подписать документ</translation>
    </message>
    <message>
        <source>Sign certificate is not selected</source>
        <translation>Сертификат подписи не выбран</translation>
    </message>
</context>
<context>
    <name>RegisterP12</name>
    <message>
        <source>No OCSP PKCS#12 certificate selected</source>
        <translation>Ни один OCSP PKCS#12 сертфикат не выбран</translation>
    </message>
    <message>
        <source>Failed to copy file</source>
        <translation>Копирование файла неуспешно</translation>
    </message>
    <message>
        <source>Select PKCS#12 certificate</source>
        <translation>Выберите PKCS#12 сертификат</translation>
    </message>
    <message>
        <source>PKCS#12 Certificates (*.p12 *.p12d)</source>
        <translation>PKCS#12 Сертификаты (*.p12 *.p12d)</translation>
    </message>
    <message>
        <source>OCSP PKCS#12 certificate installer</source>
        <translation>Установка сертификата доступа</translation>
    </message>
    <message>
        <source>OCSP PKCS#12 certificate</source>
        <translation>Сертификат доступа</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>OCSP PKCS#12 server access certificate is available at&lt;br /&gt;
&lt;a href=&quot;http://www.sk.ee/getaccess/?lang=eng&quot;&gt;http://www.sk.ee/toend/&lt;/a&gt;</source>
        <translation>Подтверждение действительности сервера справки доступа можно получить с веб-страницы SK&lt;br /&gt;
&lt;a href=&quot;http://www.sk.ee/getaccess/?lang=eng&quot;&gt;http://www.sk.ee/toend/&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Select folder</source>
        <translation>Выбрать папку</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>Container default location</source>
        <translation>Расположение контейнера по умолчанию</translation>
    </message>
    <message>
        <source>Same folder</source>
        <translation>Та же папка</translation>
    </message>
    <message>
        <source>Ask container name</source>
        <translation>Спросить название контейнера</translation>
    </message>
    <message>
        <source>Show signing intro</source>
        <translation>Показывать введение при подписывании</translation>
    </message>
    <message>
        <source>Default file type:</source>
        <translation>Тип файла по умолчанию:</translation>
    </message>
    <message>
        <source>Role</source>
        <translation>Роль</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Резолюция</translation>
    </message>
    <message>
        <source>City</source>
        <translation>Город</translation>
    </message>
    <message>
        <source>State</source>
        <translation>Уезд</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>Страна</translation>
    </message>
    <message>
        <source>Zip</source>
        <translation>Индекс</translation>
    </message>
    <message>
        <source>Save last insert role and resolution</source>
        <translation>Сохранить последнюю введённую роль и резолюцию</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Общее</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Подпись</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Прокси</translation>
    </message>
    <message>
        <source>Host</source>
        <translation>Хост</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Порт</translation>
    </message>
    <message>
        <source>Select PKCS#12 certificate</source>
        <translation>Выберите  PKCS#12 сертификат</translation>
    </message>
    <message>
        <source>PKCS#12 Certificates (*.p12 *.p12d)</source>
        <translation>PKCS#12 Сертификаты (*.p12 *.p12d)</translation>
    </message>
    <message>
        <source>OCSP PKCS#12 certificate</source>
        <translation>Сертификат доступа</translation>
    </message>
    <message>
        <source>Certificate</source>
        <translation>Сертификат</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Имя пользователя</translation>
    </message>
    <message>
        <source>If you change file format from .bdoc to .ddoc or vise versa, opened file will not change.</source>
        <translation>Невозможно изменить формат уже открытого конверта. Настройки будут действительны только для новых конвертов.</translation>
    </message>
    <message>
        <source>Show certificate</source>
        <translation>См. сертификат</translation>
    </message>
</context>
<context>
    <name>SignatureDialog</name>
    <message>
        <source>Signature is valid</source>
        <translation>Подпись действительна</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Неизвестная ошибка</translation>
    </message>
    <message>
        <source>Signing time</source>
        <translation>Время подписи</translation>
    </message>
    <message>
        <source>Signature type</source>
        <translation>Тип подписи</translation>
    </message>
    <message>
        <source>Signature format</source>
        <translation>Формат подписи</translation>
    </message>
    <message>
        <source>Signed file count</source>
        <translation>Количество подписанных файлов</translation>
    </message>
    <message>
        <source>Certificate serialnumber</source>
        <translation>Серийный номер сертификатов</translation>
    </message>
    <message>
        <source>Certificate valid at</source>
        <translation>Сертификат действителен с</translation>
    </message>
    <message>
        <source>Certificate valid until</source>
        <translation>Сертификат действителен до</translation>
    </message>
    <message>
        <source>Certificate issuer</source>
        <translation>Выдавший сертификат</translation>
    </message>
    <message>
        <source>Signer</source>
        <translation>Подписавшаяся сторона</translation>
    </message>
    <message>
        <source>Signer location</source>
        <translation>Месторасположение расписавшегося</translation>
    </message>
    <message>
        <source>City</source>
        <translation>Город</translation>
    </message>
    <message>
        <source>State</source>
        <translation>Уезд</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>Страна</translation>
    </message>
    <message>
        <source>Zip</source>
        <translation>Индекс</translation>
    </message>
    <message>
        <source>Role / resolution</source>
        <translation>Роль / резолюция</translation>
    </message>
    <message>
        <source>Show certificate</source>
        <translation>См. сертификат</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Подпись</translation>
    </message>
    <message>
        <source>Attribute</source>
        <translation>Атрибут</translation>
    </message>
    <message>
        <source>Value</source>
        <translation>Значение</translation>
    </message>
    <message>
        <source>OCSP</source>
        <translation>Подтвердить</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Время</translation>
    </message>
    <message>
        <source>Hash value of validity confirmation</source>
        <translation>Хеш-значение при подтверждении действия</translation>
    </message>
    <message>
        <source>Signature is not valid</source>
        <translation>Подпись недействительна</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Помощь</translation>
    </message>
    <message>
        <source>Signature status unknown</source>
        <translation>Неизвестный статус пользователя</translation>
    </message>
</context>
<context>
    <name>SignatureWidget</name>
    <message>
        <source>Signed on</source>
        <translation>Подписано</translation>
    </message>
    <message>
        <source>Signature is</source>
        <translation>Подпись</translation>
    </message>
    <message>
        <source>valid</source>
        <translation>действительна</translation>
    </message>
    <message>
        <source>not valid</source>
        <translation>недействительна</translation>
    </message>
    <message>
        <source>Show details</source>
        <translation>Подробнее</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>time</source>
        <translation>Время</translation>
    </message>
    <message>
        <source>Test signature</source>
        <translation>Пробная подпись</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>Неизвестно</translation>
    </message>
    <message>
        <source>Remove signature %1</source>
        <translation>Удалить подпись %1</translation>
    </message>
</context>
<context>
    <name>TreeWidget</name>
    <message>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Save file</source>
        <translation>Сохранить файл</translation>
    </message>
</context>
</TS>
